@@ -4,8 +4,10 @@
 #
 from ebbe.iter import (
     as_chunks,
+    as_grams,
     fail_fast,
     uniq,
+    distinct,
     with_prev,
     with_prev_and_next,
     with_next,
@@ -15,7 +17,14 @@ from ebbe.iter import (
 )
 from ebbe.utils import (
     noop,
+    get,
+    getter,
     getpath,
     pathgetter,
-    sorted_uniq
+    sorted_uniq,
+    indexed,
+    grouped,
+    partitioned,
+    grouped_items,
+    partitioned_items
 )
